@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 # shellcheck disable=SC2034
-export source="${BASH_SOURCE[0]}"; debug.sh source
+export starting="${BASH_SOURCE[0]}"; debug.sh starting
 
 if ! isuser.sh; then
   error.sh "can not be done with root"; exit 1
@@ -11,7 +11,7 @@ if name="$( source gtop 2>&1 )"; then
   path="$( git rev-parse --show-toplevel 2>&1 )"; export path; debug.sh path
   cd "${path}" || { error.sh cd "${path}"; exit 1; }
   branch="$( git rev-parse --abbrev-ref HEAD )"
-  debug branch
+  debug.sh branch
   if [[ "${branch}" != 'master' ]]; then
     git checkout master || exit 1
     git merge "${branch}" || exit 1
@@ -26,4 +26,4 @@ else
   error.sh gall "${name}"; exit 1
 fi
 
-unset source name path error branch
+unset starting name path error branch
