@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 # shellcheck disable=SC2034
-export source="${BASH_SOURCE[0]}"; debug.sh source
+export starting="${BASH_SOURCE[0]}"; debug.sh starting
 
 if isuserdarwin.sh; then
   test -n "${GITHUB_SECRETS_PATH}" || { error.sh GITHUB_SECRETS_PATH 'not defined'; exit 1; }
@@ -9,4 +9,4 @@ if isuserdarwin.sh; then
   cd - > /dev/null || exit 1
 fi
 
-unset source
+unset starting
